# What do you need to access the output database?

To use the Abaqus Scripting Interface to access an output database, you need to understand the following:

- How an Abaqus analysis outputs data to the output database as well as the difference between field data, history data, and model data. The output database is described in detail in [Output to the Output Database](https://help.3ds.com/2021/English/DSSIMULIA_Established/SIMACAEOUTRefMap/simaout-m-dboutput-sb.htm?contextscope=all#simaout-m-dboutput-sb) and [Assembly definition](https://help.3ds.com/2021/English/DSSIMULIA_Established/SIMACAEMODRefMap/simamod-c-partassy.htm?contextscope=all).
- How to program using Python. An introduction to the Python programming language is provided in {doc}`/user/python/introduction`.
- How to use Abaqus objects. Abaqus objects are explained in {doc}`/user/python/python-abaqus`.
